@@ -3,7 +3,7 @@ package CLDR::Number;
 use utf8;
 use Moo;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 with qw( CLDR::Number::Role::Base );
 
@@ -50,7 +50,7 @@ CLDR::Number - Localized number formatters using the Unicode CLDR
 
 =head1 VERSION
 
-This document describes CLDR::Number v0.02, built with the Unicode CLDR v24.
+This document describes CLDR::Number v0.03, built with the Unicode CLDR v24.
 This is an early release without full documentation. See L<CLDR::Number::TODO>.
 
 =head1 SYNOPSIS
@@ -202,7 +202,7 @@ L<code.shutterstock.com|http://code.shutterstock.com/>.
 
 =head1 COPYRIGHT AND LICENSE
 
-© 2013 Shutterstock, Inc.
+© 2013–2014 Shutterstock, Inc.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
